<?php

namespace TelegramApi\Types;

class InlineKeyboardButton implements TypeInterface
{
	/** @var string Label text on the button */
	public string $text;

	/** @var string|null Optional. HTTP or tg:// URL to be opened when the button is pressed. Links tg://user?id=<user_id> can be used to mention a user by their ID without using a username, if this is allowed by their privacy settings. */
	public ?string $url = null;

	/** @var string|null Optional. Data to be sent in a callback query to the bot when button is pressed, 1-64 bytes */
	public ?string $callbackData = null;

	/** @var WebAppInfo|null Optional. Description of the Web App that will be launched when the user presses the button. The Web App will be able to send an arbitrary message on behalf of the user using the method answerWebAppQuery. Available only in private chats between a user and the bot. */
	public ?WebAppInfo $webApp = null;

	/** @var LoginUrl|null Optional. An HTTPS URL used to automatically authorize the user. Can be used as a replacement for the Telegram Login Widget. */
	public ?LoginUrl $loginUrl = null;

	/** @var string|null Optional. If set, pressing the button will prompt the user to select one of their chats, open that chat and insert the bot's username and the specified inline query in the input field. May be empty, in which case just the bot's username will be inserted. */
	public ?string $switchInlineQuery = null;

	/** @var string|null Optional. If set, pressing the button will insert the bot's username and the specified inline query in the current chat's input field. May be empty, in which case only the bot's username will be inserted.This offers a quick way for the user to open your bot in inline mode in the same chat - good for selecting something from multiple options. */
	public ?string $switchInlineQueryCurrentChat = null;

	/** @var SwitchInlineQueryChosenChat|null Optional. If set, pressing the button will prompt the user to select one of their chats of the specified type, open that chat and insert the bot's username and the specified inline query in the input field */
	public ?SwitchInlineQueryChosenChat $switchInlineQueryChosenChat = null;

	/** @var CallbackGame|null Optional. Description of the game that will be launched when the user presses the button.NOTE: This type of button must always be the first button in the first row. */
	public ?CallbackGame $callbackGame = null;

	/** @var bool|null Optional. Specify True, to send a Pay button.NOTE: This type of button must always be the first button in the first row and can only be used in invoice messages. */
	public ?bool $pay = null;
}
