<?php

namespace TelegramApi\Types;

class ReplyParameters implements TypeInterface
{
	/** @var int Identifier of the message that will be replied to in the current chat, or in the chat chat_id if it is specified */
	public int $messageId;

	/** @var int|string|null Optional. If the message to be replied to is from a different chat, unique identifier for the chat or username of the channel (in the format @channelusername) */
	public int|string|null $chatId = null;

	/** @var bool|null Optional. Pass True if the message should be sent even if the specified message to be replied to is not found; can be used only for replies in the same chat and forum topic. */
	public ?bool $allowSendingWithoutReply = null;

	/** @var string|null Optional. Quoted part of the message to be replied to; 0-1024 characters after entities parsing. The quote must be an exact substring of the message to be replied to, including bold, italic, underline, strikethrough, spoiler, and custom_emoji entities. The message will fail to send if the quote isn't found in the original message. */
	public ?string $quote = null;

	/** @var string|null Optional. Mode for parsing entities in the quote. See formatting options for more details. */
	public ?string $quoteParseMode = null;

	/** @var Array<MessageEntity>|null Optional. A JSON-serialized list of special entities that appear in the quote. It can be specified instead of quote_parse_mode. */
	public ?array $quoteEntities = null;

	/** @var int|null Optional. Position of the quote in the original message in UTF-16 code units */
	public ?int $quotePosition = null;
}
